package
Version:
v0.0.0-...-01ca449
Opens a new window with list of versions in this module.
Published: Jan 15, 2026
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ScaffoldService interface {
CreateProject(name string) error
CreateProjectWithStrategy(name, strategyExample string) error
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.